<?php
defined('BASEPATH') or exit('No direct script access allowed');

class Admin extends CI_Controller
{
    public function __construct()
    {
        parent::__construct();
        $this->load->library('auth');
        $this->auth->check_login();
        $this->load->model('User_model');
        $this->load->model('M_lansia');
        $this->load->model('M_agenda');
        $this->load->library('session');
        $this->no_cache();
    }

    private function no_cache()
    {
        $this->output->set_header('Last-Modified: ' . gmdate('D, d M Y H:i:s') . ' GMT');
        $this->output->set_header('Cache-Control: no-store, no-cache, must-revalidate, max-age=0');
        $this->output->set_header('Cache-Control: post-check=0, pre-check=0', false);
        $this->output->set_header('Pragma: no-cache');
    }

    // Fungsi untuk menampilkan dashboard admin
    public function dashboard()
    {
        if ($this->session->userdata('role') != 'admin') {
            redirect('login');
        }

        $data['judul'] = 'Dashboard Admin';
        $data['total_lansia'] = $this->M_lansia->countLansia();
        $data['total_laki_laki'] = $this->M_lansia->countLakiLaki();
        $data['total_perempuan'] = $this->M_lansia->countPerempuan();
        $data['total_sehat'] = $this->M_lansia->get_total_sehat();
        $data['total_tidak_sehat'] = $this->M_lansia->get_total_tidak_sehat();

        $data['last_agenda'] = $this->M_agenda->get_last_agenda();

        // Ambil jumlah pengguna
        $data['total_kader'] = $this->User_model->countKader();
        $data['total_bidan'] = $this->User_model->countBidan();
        $data['total_admin'] = $this->User_model->countAdmin();
        $data['total_users'] = $this->User_model->countTotalUsers(); // Total pengguna

        $this->load->view('admin/headeradmin', $data);
        $this->load->view('admin/dashboard', $data);
        $this->load->view('admin/footeradmin');
    }

    // Fungsi untuk menampilkan form registrasi
    public function register()
    {
        $data['judul'] = 'Registrasi User';
        $this->load->view('admin/headeradmin', $data);
        $this->load->view('admin/register_user');
        $this->load->view('admin/footeradmin');
    }

    // Fungsi untuk memproses registrasi
    public function register_user_process()
    {
        // Ambil data dari form
        $nama = $this->input->post('nama');
    $username = $this->input->post('username');
    $password = password_hash($this->input->post('password'), PASSWORD_DEFAULT); // password diambil dari form
    // $tempat_lahir = $this->input->post('tempat_lahir');
    // $tanggal_lahir = $this->input->post('tanggal_lahir');
    // $usia = $this->input->post('usia');
    // $alamat = $this->input->post('alamat');
    // $agama = $this->input->post('agama');
    // $pendidikan_terakhir = $this->input->post('pendidikan_terakhir');
    // $email = $this->input->post('email');
    // $no_hp = $this->input->post('no_hp');
    $role = $this->input->post('role');

        // Hash password (gunakan password_hash yang lebih aman)
        

        // Cek apakah username atau NIK sudah ada
        if ($this->User_model->get_user_by_username($username)) {
        $this->session->set_flashdata('error', 'Username sudah digunakan.');
        redirect('admin/register');
        } else {
            // Data yang akan dimasukkan ke database
            $data = array(
            'nama' => $nama,
            'username' => $username,
            'password' => $password,
            // 'tempat_lahir' => $tempat_lahir,
            // 'tanggal_lahir' => $tanggal_lahir,
            // 'usia' => $usia,
            // 'alamat' => $alamat,
            // 'agama' => $agama,
            // 'pendidikan_terakhir' => $pendidikan_terakhir,
            // 'email' => $email,
            // 'no_hp' => $no_hp,
            'role' => $role,
        );

            // Simpan ke database
            if ($this->User_model->insert_user($data)) {
                $this->session->set_flashdata('success', 'Pengguna berhasil didaftarkan. Tunggu persetujuan admin.');
                redirect('admin/dashboard'); 
            } else {
                $this->session->set_flashdata('error', 'Terjadi kesalahan saat mendaftarkan pengguna.');
                redirect('admin/register');
            }
        }
    }

    public function daftarpengguna()
    {
        $data['judul'] = 'Manajemen Akun';
    
        // Memanggil model untuk mengambil semua data user
        $this->load->model('User_model'); // Pastikan model ini sudah dibuat
        $data['daftar_akun'] = $this->User_model->getAllUsers();
    
        // Jika ada pencarian
        if ($this->input->post('keyword')) {
            $data['daftar_akun'] = $this->User_model->cariAkun($this->input->post('keyword'));
        }
    
        $this->load->view('admin/headeradmin', $data);
        $this->load->view('admin/daftarpengguna', $data);
        $this->load->view('admin/footeradmin');
    }

    public function hapusakun($id)
{
    $this->load->model('User_model');
    $this->User_model->hapusUser($id);
    $this->session->set_flashdata('flash', 'dihapus');
    redirect('admin/daftarpengguna');
}

public function editakun($id)
{
    $this->load->model('User_model');
    $data['judul'] = 'Edit Akun';
    $data['akun'] = $this->User_model->getUserById($id);

    $this->form_validation->set_rules('nama', 'Nama', 'required');
    $this->form_validation->set_rules('username', 'Username', 'required');

    if ($this->form_validation->run() == FALSE) {
        $this->load->view('admin/headeradmin', $data);
        $this->load->view('admin/edit_akun', $data);
        $this->load->view('admin/footeradmin');
    } else {
        $this->User_model->updateUser();
        $this->session->set_flashdata('flash', 'diedit');
        redirect('admin/daftarpengguna');
    }
}

}
?>
