<?php
class Bidan extends CI_Controller {
    public function __construct() {
        parent::__construct();
        $this->load->library('auth');
        $this->auth->check_login();
        $this->no_cache();
    }

    private function no_cache() {
        $this->output->set_header('Last-Modified: ' . gmdate('D, d M Y H:i:s') . ' GMT');
        $this->output->set_header('Cache-Control: no-store, no-cache, must-revalidate, max-age=0');
        $this->output->set_header('Cache-Control: post-check=0, pre-check=0', false);
        $this->output->set_header('Pragma: no-cache');
    }

    public function dashboard() {
        if ($this->session->userdata('role') != 'bidan') {
            redirect('login');
        }
        $data['judul'] = 'Dashboard Bidan';
        // hitung jumlah sehat dan tidak sehat
        $data['sehat'] = $this->db->where('keterangan', 'Sehat')->count_all_results('data_lansia');
        $data['tidak_sehat'] = $this->db->where('keterangan', 'Tidak Sehat')->count_all_results('data_lansia');

        // Ambil semua data riwayat lansia
        $this->db->select('nik, tanggal_periksa');
        $riwayat = $this->db->get('riwayat_kesehatan')->result();

        // Siapkan array untuk menyimpan per bulan
        $bulanAktif = array_fill(1, 12, 0);
        $bulanPasif = array_fill(1, 12, 0);

        // Proses data per bulan
        $dataBulan = [];

        foreach ($riwayat as $r) {
            $bulan = (int) date('n', strtotime($r->tanggal_periksa)); // Ambil bulan dari tanggal_periksa
            if (!isset($dataBulan[$bulan])) {
                $dataBulan[$bulan] = [];
            }
            $dataBulan[$bulan][] = $r->nik;
        }

        foreach ($dataBulan as $bulan => $niks) {
            $hitung = array_count_values($niks);

            foreach ($hitung as $nik => $jumlahPeriksa) {
                if ($jumlahPeriksa > 1) {
                    $bulanAktif[$bulan]++;
                } else {
                    $bulanPasif[$bulan]++;
                }
            }
        }

        $data['bulanAktif'] = $bulanAktif;
        $data['bulanPasif'] = $bulanPasif;

            // Ambil tanggal pemeriksaan terbaru
    $this->db->select_max('tanggal_periksa');
    $query = $this->db->get('riwayat_kesehatan')->row();
    $tanggal_terbaru = $query->tanggal_periksa;

    // Ambil data pemeriksaan pada tanggal terbaru itu
    $this->db->where('tanggal_periksa', $tanggal_terbaru);
    $pemeriksaan = $this->db->get('riwayat_kesehatan')->result();

    // Hitung jumlah masing-masing kategori
    $asam_urat = 0;
    $gula_darah = 0;
    $kolesterol = 0;
    $tekanan_darah = 0;

    foreach ($pemeriksaan as $p) {
        if ($p->asam_urat > 7) $asam_urat++;
        if ($p->gula_darah > 140) $gula_darah++;
        if ($p->kolesterol > 200) $kolesterol++;

        // Tekanan darah format 120/80
        $tekanan = explode('/', $p->tekanan_darah);
        if (count($tekanan) == 2) {
            $sistolik = (int) $tekanan[0];
            $diastolik = (int) $tekanan[1];
            if ($sistolik > 130 || $diastolik > 90 || $sistolik < 90 || $diastolik < 60) {
                $tekanan_darah++;
            }
        }
    }

    // kirim data ke view
    $data['grafik_pemeriksaan'] = [
        'asam_urat' => $asam_urat,
        'gula_darah' => $gula_darah,
        'kolesterol' => $kolesterol,
        'tekanan_darah' => $tekanan_darah
    ];
    $data['tanggal_terbaru'] = $tanggal_terbaru;


        $this->load->view('bidan/headerbidan', $data);
        $this->load->view('bidan/dashboard');
        $this->load->view('bidan/footerbidan');
    }
}
?>
